package gestion;

import java.time.LocalDate;

/**
 * Esta clase representa un Encargo con los atributos necesarios para su gestion:
 * empleado que lo hizo, producto, observaciones, datos de cliente y fecha de creación.
 * La fecha de creación es automática y no es modificable por el usuario.
 */
public final class Encargo{
	
	private String empleado;
	private String producto;
	private String observaciones;
	private String nombreCliente;
	private String telefonoCliente;
	private final LocalDate FECHA = LocalDate.now();
	
	public Encargo(String empleado, String producto, String obser, String nomCli, String telef) {
		this.empleado = empleado;
		this.producto = producto;
		observaciones = obser;
		nombreCliente = nomCli;
		telefonoCliente = telef;
	}

	public String getEmpleado() {
		return empleado;
	}

	public void setEmpleado(String empleado) {
		this.empleado = empleado;
	}

	public String getProducto() {
		return producto;
	}

	public void setProducto(String producto) {
		this.producto = producto;
	}

	public String getObservaciones() {
		return observaciones;
	}

	public void setObservaciones(String observaciones) {
		this.observaciones = observaciones;
	}

	public String getNombreCliente() {
		return nombreCliente;
	}

	public void setNombreCliente(String nombreCliente) {
		this.nombreCliente = nombreCliente;
	}

	public String getTelefonoCliente() {
		return telefonoCliente;
	}

	public void setTelefonoCliente(String telefonoCliente) {
		this.telefonoCliente = telefonoCliente;
	}

	public LocalDate getFecha() {
		return FECHA;
	}
	
	public String getFechaFormateada() {
		int dia = FECHA.getDayOfMonth();
		int mes = FECHA.getMonthValue();
		int anio = FECHA.getYear();
		return String.format("%02d/%02d/%4d", dia, mes, anio);
	}

}
