package gestion;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.ScrollPaneConstants;
import javax.swing.SwingUtilities;

import gui.PanelEncargo;

public final class Vista {

	private Controlador controlador;
	private JScrollPane scroll;
	private JPanel contenedor;

	public Vista(Controlador c) {
		controlador = c;
		creaGUI();
	}

	private void creaGUI() {
		try {
			SwingUtilities.invokeAndWait(new Runnable(){
				@Override
				public void run() {
					contenedor = new JPanel();
					scroll = new JScrollPane(contenedor);
					scroll.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_AS_NEEDED);
					scroll.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
					contenedor.setLayout(new BoxLayout(contenedor, BoxLayout.Y_AXIS));
					contenedor.setMaximumSize(new Dimension(800, 600));
				}		
			}
					);
		} catch (InvocationTargetException | InterruptedException e) {
			e.printStackTrace();
		}
	}

	/**
	 * Retorna el JScrollPane para que el JFrame principal lo muestre en pantalla
	 * @return El JScrollPane donde se van mostrando los Paneles de Encargos.
	 */
	public JScrollPane getContenedor() {
		return scroll;
	}

	/**
	 * Actualiza en pantalla los Paneles de Encargos según los Encargos que hay actualmente
	 * en el ArrayList de la clase Modelo.
	 * Para ello cada vez que se ejecuta elimina todos los componentes presentes en pantalla
	 * y vuelve a generarlos de nuevo según lo que encuentra en el ArrayList recibido.
	 * @param encargos ArrayList con los Encargos actuales, se recibe desde el Modelo.
	 */
	public void actualizarEncargos(ArrayList<Encargo> encargos) {
		contenedor.removeAll();
		System.out.println("Encargos.size() --> " + encargos.size()); //Info para debug
		for (int i = 0; i < encargos.size(); i++)
		{
			PanelEncargo temp = new PanelEncargo(encargos.get(i));
			temp.botonEliminar.addActionListener(new AccionEliminarPanel(i));
			contenedor.add(Box.createRigidArea(new Dimension(0, 20)), -1);
			contenedor.add(temp);
		}
		contenedor.revalidate();
	}


	/**
	 * Clase de Accion para eliminar paneles.
	 * Esta accion se añade al boton "Eliminar" de cada PanelEncargo presentado en pantalla.
	 * Posee un atributo llamado numeroPanel que sirve para identificar cada panel.
	 * El valor de este atributo se recibe por el contructor y corresponde con el indice que apunta
	 * al Encargo almacenado en el ArrayList en la clase Modelo.
	 * De este modo, al pulsar el boton "Eliminar" el Controlador puede decirle al Modelo que Encargo
	 * ha de eliminar en el ArrayList.
	 */
	private class AccionEliminarPanel implements ActionListener {
		
		int numeroPanel;
		
		public AccionEliminarPanel(int nPanel) {
			numeroPanel = nPanel;
		}
		
		@Override
		public void actionPerformed(ActionEvent e) {
			System.out.println("Eliminando panel numero: " + numeroPanel); //Info para debug
			controlador.eliminarEncargo(numeroPanel);
		}
	}
}
