package gui;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.FlowLayout;
import java.awt.Frame;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.JButton;

import gestion.Encargo;

/**
 * Muestra una ventana de Dialogo con un formulario de campos donde el usuario
 * puede introducir los datos necesarios para crear un nuevo Encargo o bien para
 * modificar uno existente.
 * En el constructor recibe un Encargo. Si este objeto es null, es que estamos creando
 * un nuevo Encargo. Si no es null, significará que estamos modificando un Encargo ya
 * existente.
 * Tanto el constructor como algunos métodos tendrán un funcionamiento distinto según si
 * estamos modificando un Encargo o no.
 */
@SuppressWarnings("serial")
public class DialogoEncargo extends JDialog{

	private Encargo encargo;
	private boolean modificando;
	private MiLabel etiqEmpleado = new MiLabel("Empleado: ");
	private MiCampo campoEmpleado = new MiCampo(12);
	private MiLabel etiqProducto = new MiLabel("Producto: ");
	private MiCampo campoProducto = new MiCampo(12);
	private MiLabel etiqObservaciones = new MiLabel("Observaciones: ");
	private MiCampo campoObservaciones = new MiCampo(12);
	private MiLabel etiqCliente = new MiLabel("Cliente: ");
	private MiCampo campoCliente = new MiCampo(12);
	private MiLabel etiqTelefono = new MiLabel("Teléfono: ");
	private MiCampo campoTelefono = new MiCampo(12);
	public JButton btAceptar = new JButton("Aceptar");
	private JButton btCancelar = new JButton("Cancelar");

	public DialogoEncargo(Frame parent, Encargo encargo) {
		super(parent, true);
		this.encargo = encargo;
		if (encargo != null) //Significa que estamos modificando un encargo existente
		{
			setTitle("Editar Encargo");
			setCampos();
			modificando = true;
		}
		else
		{
			setTitle("Nuevo Encargo");
			modificando = false;
		}
		//Panel central con campos
		JPanel centro = new JPanel();
		centro.setLayout(new GridLayout(5, 2, 2, 5));
		centro.add(new PanelIzq(etiqEmpleado));
		centro.add(new PanelDer(campoEmpleado));
		centro.add(new PanelIzq(etiqProducto));
		centro.add(new PanelDer(campoProducto));
		centro.add(new PanelIzq(etiqObservaciones));
		centro.add(new PanelDer(campoObservaciones));
		centro.add(new PanelIzq(etiqCliente));
		centro.add(new PanelDer(campoCliente));
		centro.add(new PanelIzq(etiqTelefono));
		centro.add(new PanelDer(campoTelefono));
		
		//Panel sur con botones
		btAceptar.setFont(new MiVerdana(1, 20));
		btAceptar.setFocusPainted(false);
		btCancelar.setFont(new MiVerdana(1, 20));
		btCancelar.setFocusPainted(false);
		btCancelar.addActionListener(new AccionCerrar());
		JPanel sur = new JPanel();
		sur.setLayout(new BoxLayout(sur, BoxLayout.X_AXIS));
		sur.add(Box.createRigidArea(new Dimension(50, 45)));
		sur.add(btAceptar);
		sur.add(Box.createHorizontalGlue());
		sur.add(btCancelar);
		sur.add(Box.createRigidArea(new Dimension(50, 45)));
		//Layout principal
		setLayout(new BorderLayout());
		add(centro, BorderLayout.CENTER);
		add(sur, BorderLayout.SOUTH);
		setDefaultCloseOperation(DISPOSE_ON_CLOSE);
		pack();
		setResizable(false);
		setLocationRelativeTo(null);
	}
	
	/**
	 * Recupera los datos de los campos de texto para retornar un Encargo
	 * actualizado.
	 * Si estamos "modificando" un Encargo ya existente, se actualiza el Encargo
	 * recibido por parametros y se retorna. De este modo no se altera la fecha original
	 * de creacion.
	 * Si NO estamos "modificando" un Encargo existente, se creará uno nuevo con los datos
	 * recogidos y con la fecha actual.
	 * @return Objeto Encargo ya sea nuevo o una modificación de uno existente
	 */
	public Encargo getEncargo() {
		if (modificando)//Solo actualizamos campos, se respeta fecha
		{
			encargo.setEmpleado(campoEmpleado.getText());
			encargo.setProducto(campoProducto.getText());
			encargo.setObservaciones(campoObservaciones.getText());
			encargo.setNombreCliente(campoCliente.getText());
			encargo.setTelefonoCliente(campoTelefono.getText());
			return encargo;
		}
		else
			return new Encargo(campoEmpleado.getText(), campoProducto.getText(),
					campoObservaciones.getText(), campoCliente.getText(),
					campoTelefono.getText());
	}

	/**
	 * Recupera los datos del Encargo recibido por parametros y los
	 * muestra en los campos correspondientes.
	 * Esto solo ocurre cuando estamos "modificando" un Encargo
	 * ya existente.
	 */
	private void setCampos() {
		campoEmpleado.setText(encargo.getEmpleado());
		campoProducto.setText(encargo.getProducto());
		campoObservaciones.setText(encargo.getObservaciones());
		campoCliente.setText(encargo.getNombreCliente());
		campoTelefono.setText(encargo.getTelefonoCliente());
	}

	/**
	 * Cierra esta ventana de Dialogo.
	 * Este método se invoca desde una clase de Accion
	 * que se añadirá al boton "Cerrar"
	 */
	private void cerrar() {
		dispose();
	}
	//Clases
	private class MiLabel extends JLabel {

		public MiLabel(String txt) {
			super(txt);
			setFont(new MiVerdana(0, 22));
		}
	}

	private class MiCampo extends JTextField {

		public MiCampo(int size) {
			super(size);
			setFont(new MiVerdana(0, 18));
		}
	}
	
	private class PanelIzq extends JPanel {
		public PanelIzq(MiLabel ml) {
			setLayout(new FlowLayout(FlowLayout.RIGHT));
			add(ml);
		}
	}
	
	private class PanelDer extends JPanel {
		public PanelDer(MiCampo mc) {
			setLayout(new FlowLayout(FlowLayout.LEFT));
			add(mc);
		}
	}
	
	/**
	 * Clase de Accion sencilla para poder cerrar esta ventana de Dialogo
	 * mediante el boton "Cerrar"
	 */
	private class AccionCerrar implements ActionListener {
		@Override
		public void actionPerformed(ActionEvent e) {
			cerrar();
		}
	}

}
