package gui;

import java.awt.Color;
import java.awt.Dimension;
import java.time.LocalDate;

import javax.swing.BorderFactory;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.border.BevelBorder;

import gestion.Encargo;

/**
 * Esta clase crea un JPanel mostrando los datos contenidos en el objeto Encargo
 * que recibe por el constructor.
 * El color de fondo varía según la antigüedad indicada por la fecha del Encargo recibido.
 * De este modo se representa visualmente si es un Encargo reciente (color verde), si es un
 * Encargo que ya empieza a tener cierta antigüedad (colo amarillo) o si es un Encargo con
 * demasiada antigüedad (color rojo).
 */
public final class PanelEncargo extends JPanel{
	
	//private int numPanel;
	private Encargo encargo;
	private JLabel etiqEmpleado;
	private JLabel etiqProducto;
	private JLabel etiqFecha;
	private JLabel etiqObservaciones;
	private JLabel etiqCliente;
	private JLabel etiqTelefono;
	public JButton botonModificar;
	public JButton botonEliminar;
	
	public PanelEncargo(Encargo encargo) {
		//numPanel = numero;
		this.encargo = encargo;
		etiqEmpleado = new JLabel("Empleado: " + encargo.getEmpleado());
		etiqEmpleado.setFont(new MiVerdana(0, 18));
		etiqProducto = new JLabel(encargo.getProducto());
		etiqProducto.setFont(new MiVerdana(1, 22));
		etiqFecha = new JLabel("Fecha: " + encargo.getFechaFormateada());
		etiqFecha.setFont(new MiVerdana(0, 18));
		etiqObservaciones = new JLabel(encargo.getObservaciones());
		etiqObservaciones.setFont(new MiVerdana(2, 18));
		etiqCliente = new JLabel("Cliente: " + encargo.getNombreCliente());
		etiqCliente.setFont(new MiVerdana(0, 18));
		etiqTelefono = new JLabel("Teléfono: " + encargo.getTelefonoCliente());
		etiqTelefono.setFont(new MiVerdana(0, 18));
		botonModificar = new JButton("Modificar");
		botonModificar.setFont(new MiVerdana(1, 18));
		botonModificar.setFocusPainted(false);
		botonModificar.setToolTipText("Modificar este encargo");
		botonEliminar = new JButton("Eliminar");
		botonEliminar.setFont(new MiVerdana(1, 18));
		botonEliminar.setFocusPainted(false);
		botonEliminar.setToolTipText("Eliminar este encargo");
		setMaximumSize(new Dimension(740, 170));
		setBorder(BorderFactory.createBevelBorder(BevelBorder.RAISED));
		setBackground(estableceColorFondo());
		setLayout(new BoxLayout(this, BoxLayout.Y_AXIS));
		//Primera linea. Empleado y Fecha
		JPanel linea1 = new JPanel();
		linea1.setBackground(null);
		linea1.setMaximumSize(new Dimension(740, 25));
		linea1.setLayout(new BoxLayout(linea1, BoxLayout.X_AXIS));
		linea1.add(etiqEmpleado);
		linea1.add(Box.createHorizontalGlue());
		linea1.add(etiqFecha);
		//Segunda linea. Producto
		JPanel linea2 = new JPanel();
		linea2.setBackground(null);
		linea2.setMaximumSize(new Dimension(740, 35));
		linea2.add(etiqProducto);
		//Tercera linea. Observaciones
		JPanel linea3 = new JPanel();
		linea3.setBackground(null);
		linea3.setMaximumSize(new Dimension(740, 30));
		linea3.add(etiqObservaciones);
		//Cuarta linea. Cliente y telefono
		JPanel linea4 = new JPanel();
		linea4.setBackground(null);
		linea4.setMaximumSize(new Dimension(740, 25));
		linea4.setLayout(new BoxLayout(linea4, BoxLayout.X_AXIS));
		linea4.add(etiqCliente);
		linea4.add(Box.createHorizontalGlue());
		linea4.add(etiqTelefono);
		//Quinta linea. Botones
		JPanel linea5 = new JPanel();
		linea5.setBackground(null);
		linea5.setMaximumSize(new Dimension(740, 40));
		linea5.setLayout(new BoxLayout(linea5, BoxLayout.X_AXIS));
		linea5.add(Box.createRigidArea(new Dimension(150, 40)));
		linea5.add(botonModificar);
		linea5.add(Box.createHorizontalGlue());
		linea5.add(botonEliminar);
		linea5.add(Box.createRigidArea(new Dimension(150, 40)));
		add(linea1);
		add(linea2);
		add(linea3);
		add(linea4);
		add(linea5);
	}
	
	/*
	public int getNumeroPanel() {
		return numPanel;
	}*/
	
	private Color estableceColorFondo() {
		LocalDate ahora = LocalDate.now();
		int diasAntiguedad = ahora.getDayOfYear() - encargo.getFecha().getDayOfYear();
		if (diasAntiguedad < 15)
			return Color.GREEN;
		else if (diasAntiguedad < 30)
			return Color.YELLOW;
		else
			return Color.RED;		
	}

}
